import { ApolloClient } from '@apollo/client';
import { LinksResult, Link } from './minilinks';
export interface PackagerPackage {
    package?: string;
    data: PackagerPackageItem[];
    strict?: boolean;
    errors?: PackagerError[];
}
export interface PackagerPackageItem {
    id: number | string;
    type?: number | string;
    from?: number | string;
    to?: number | string;
    value?: PackagerValue;
}
export interface PackagerValue {
    [key: string]: any;
}
export declare type PackagerError = any;
export interface PackagerImportResult {
    errors?: PackagerError[];
}
export declare type PackagerMutated = {
    [index: number]: boolean;
};
export interface PackagerExportOptions {
    packageLinkId: number;
}
export interface PackagerLink extends Link<any> {
    value?: any;
}
export declare function deserialize(pckg: PackagerPackage, errors?: PackagerError[]): {
    data: PackagerPackageItem[];
    errors?: PackagerError[];
    counter: number;
};
export declare function sort(pckg: PackagerPackage, data: PackagerPackageItem[], errors?: PackagerError[]): {
    sorted: any[];
};
export declare class Packager {
    pckg: PackagerPackage;
    client: ApolloClient<any>;
    constructor(client: ApolloClient<any>);
    fetchTableNamesValuedToTypeId(types: number[], errors: PackagerError[]): Promise<{
        [type: string]: string;
    }>;
    insertItem(id: number, items: PackagerPackageItem[], item: PackagerPackageItem, errors: PackagerError[], mutated: PackagerMutated): Promise<void>;
    insertItems(pckg: PackagerPackage, data: PackagerPackageItem[], counter: number, errors?: PackagerError[], mutated?: {
        [index: number]: boolean;
    }): Promise<void>;
    import(pckg: PackagerPackage): Promise<PackagerImportResult>;
    selectLinks(options: PackagerExportOptions): Promise<LinksResult<PackagerLink>>;
    serialize(globalLinks: LinksResult<PackagerLink>, options: PackagerExportOptions, pckg: PackagerPackage): Promise<void>;
    export(options: PackagerExportOptions): Promise<PackagerPackage>;
}
